
import subprocess,os
import imp
def TTSnorm(text, punc = False, unknown = True, lower = True, rule = False ):
    A=imp.find_module('vinorm')[1]

    #print(A)
    I=A+"/input.txt"
    with open(I,"w+") as fw:
        fw.write(text)

    myenv = os.environ.copy()
    myenv['LD_LIBRARY_PATH'] = A+'/lib'

    E=A+"/main"
    #print(E)
    # if punc:
    #     E=E+" -punc"
    # if unknown:
    #     E=E+" -unknown"
    # if lower:
    #     E=E+" -lower"
    # if rule:
    #     E=E+" -rule"
    subprocess.check_call([E], "-punc", env=myenv, cwd=A)
    
    O=A+"/output.txt"
    with open(O,"r") as fr:
        text=fr.read()
    TEXT=""
    S=text.split("#line#")
    for s in S:
        if s=="":
            continue
        TEXT+=s+". "


    return TEXT